compute_program_hash_chain

Function compute_program_hash_chain 

pub fn compute_program_hash_chain(
    program: &StrippedProgram,
    bootloader_version: usize,
    program_hash_function: HashFunc,
) -> Result<Felt, ProgramHashError>
Computes the program hash chain using the selected hash function. This implementation takes into account the program header in addition to the program data, which aligns with how the bootloader computes the program hash of its subtasks.