Module vars

Module vars 

Constants

AGGREGATOR_FACT_TOPOLOGIES
Aggregator fact topologies for an applicative bootloader run.
APPLICATIVE_BOOTLOADER_INPUT
Deserialized applicative bootloader input.
APPLICATIVE_OUTPUT_BUILTIN_STATE
Saved state of the output builtin for an applicative bootloader run.
BOOTLOADER_INPUT
Deserialized bootloader input.
COMPONENT_HEIGHT
FACT_TOPOLOGIES
Fact topologies.
MOCK_CAIRO_VERIFIER_INPUT
Mock Cairo verifier input.
N_BUILTINS
Number of builtins used by the program.
N_SELECTED_BUILTINS
Number of selected builtins for the current program.
OUTPUT_BUILTIN_STATE
Saved state of the output builtin.
OUTPUT_PREIMAGE_DUMP_PATH
Path to dump the output preimage for privacy simple bootloader.
OUTPUT_RUNNER_DATA
Output builtin additional data.
OUTPUT_START
Output builtin segment start.
PACKED_OUTPUT
Packed output for the current task.
PACKED_OUTPUTS
Packed outputs.
PRE_EXECUTION_BUILTIN_PTRS
“pre_execution_builtin_ptrs”
PROGRAM_ADDRESS
Address of current program.
PROGRAM_DATA_BASE
Program data segment. Used in execute_task().
PROGRAM_HASH_FUNCTION
Current simple bootloader program_hash_function.
PROGRAM_INPUT
General program input.
PROGRAM_OBJECT
General program object.
SIMPLE_BOOTLOADER_INPUT
Deserialized simple bootloader input.
SIMPLE_OUTPUT_INPUT
Simple output input.
TASK
Current simple bootloader task.
TASKS
Simple bootloader tasks.
USE_PREV_HASH