create_pie_task

Function create_pie_task 

pub fn create_pie_task(pie_path: &Path) -> Result<Task, BootloaderTaskError>
Creates a TaskSpec for a Cairo PIE task by reading it from a zip file.

Arguments

  • pie_path: A reference to a Path where the Cairo PIE file is located.

Returns

  • Ok(Task): On success, returns a Task with the loaded Cairo PIE.
  • Err(BootloaderTaskError): On failure, returns a BootloaderTaskError::Pie if there’s an issue with reading the Cairo PIE file.