Module utils

Module utils 

Enums

ProgramInput

Functions

get_cairo_run_config
Creates a Cairo run configuration based on the provided parameters.
get_program
Loads a Cairo program from a file.
get_program_input_from_path
Wraps the input for a Cairo program.
write_output_to_file
Write the program output to the specified output path as Felt252 values.