get_program_input_from_path

Function get_program_input_from_path 

pub fn get_program_input_from_path(
    program_input: &Option<PathBuf>,
) -> Result<Option<ProgramInput>>
Wraps the input for a Cairo program.

This function checks if an input file is provided. If so, it returns the path wrapped as ProgramInput::Path. If no input file is provided, it returns Ok(None).

Arguments

  • program_input - An optional file path to the input file.

Errors

Returns an io::Error only for API consistency.