pub fn write_output_to_file(
runner: &mut CairoRunner,
output_path: PathBuf,
) -> Result<()>Expand description
Write the program output to the specified output path as Felt252 values.
pub fn write_output_to_file(
runner: &mut CairoRunner,
output_path: PathBuf,
) -> Result<()>Write the program output to the specified output path as Felt252 values.