Re-exports
pub use types::ApplicativeBootloaderInput;pub use types::BootloaderConfig;pub use types::BootloaderInput;pub use types::Cairo0Executable;pub use types::CairoVerifierInput;pub use types::PackedOutput;pub use types::SimpleBootloaderInput;pub use types::Task;pub use types::TaskSpec;pub use vars::APPLICATIVE_BOOTLOADER_INPUT;pub use vars::BOOTLOADER_INPUT;pub use vars::COMPONENT_HEIGHT;pub use vars::PROGRAM_INPUT;pub use vars::PROGRAM_OBJECT;pub use vars::SIMPLE_BOOTLOADER_INPUT;
Modules
Structs
- Bootloader
Hint Processor - A hint processor for use cases where we only care about the bootloader hints.
- Minimal
Bootloader Hint Processor - A hint processor that can only execute the hints defined in this library. For large projects, you may want to compose a hint processor from multiple parts (ex: Starknet OS, bootloader and Cairo VM). This hint processor is as minimal as possible to enable this modularity.
Enums
Functions
- compute_
program_ hash_ chain - Computes the program hash chain using the selected hash function. This implementation takes into account the program header in addition to the program data, which aligns with how the bootloader computes the program hash of its subtasks.