pub fn get_program_input(
program_input: &Option<PathBuf>,
) -> Result<Option<String>>Expand description
Reads the input for a Cairo program from a file.
This function checks if an input file is provided. If so, it reads the entire
content of the file into a String and returns it wrapped in Some.
If no input file is provided, it returns Ok(None).
Arguments
program_input- An optional file path to the input file.
Errors
Returns an io::Error if there is an issue reading the input file.